==> wxwidgets-common-3.2.0-4-x86_64.pkg.tar.zst: usr/lib/cmake/wxWidgets/wxWidgetsTargets-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "wx::wxbase" for configuration "None"
set_property(TARGET wx::wxbase APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxbase PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_baseu-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_baseu-3.2.so.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS wx::wxbase )
list(APPEND _IMPORT_CHECK_FILES_FOR_wx::wxbase "${_IMPORT_PREFIX}/lib/libwx_baseu-3.2.so.0.0.0" )

# Import target "wx::wxnet" for configuration "None"
set_property(TARGET wx::wxnet APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxnet PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_baseu_net-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_baseu_net-3.2.so.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS wx::wxnet )
list(APPEND _IMPORT_CHECK_FILES_FOR_wx::wxnet "${_IMPORT_PREFIX}/lib/libwx_baseu_net-3.2.so.0.0.0" )

# Import target "wx::wxcore" for configuration "None"
set_property(TARGET wx::wxcore APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxcore PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_core-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_core-3.2.so.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS wx::wxcore )
list(APPEND _IMPORT_CHECK_FILES_FOR_wx::wxcore "${_IMPORT_PREFIX}/lib/libwx_gtk3u_core-3.2.so.0.0.0" )

# Import target "wx::wxadv" for configuration "None"
set_property(TARGET wx::wxadv APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxadv PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_adv-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_adv-3.2.so.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS wx::wxadv )
list(APPEND _IMPORT_CHECK_FILES_FOR_wx::wxadv "${_IMPORT_PREFIX}/lib/libwx_gtk3u_adv-3.2.so.0.0.0" )

# Import target "wx::wxaui" for configuration "None"
set_property(TARGET wx::wxaui APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxaui PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_aui-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_aui-3.2.so.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS wx::wxaui )
list(APPEND _IMPORT_CHECK_FILES_FOR_wx::wxaui "${_IMPORT_PREFIX}/lib/libwx_gtk3u_aui-3.2.so.0.0.0" )

# Import target "wx::wxhtml" for configuration "None"
set_property(TARGET wx::wxhtml APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxhtml PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_html-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_html-3.2.so.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS wx::wxhtml )
list(APPEND _IMPORT_CHECK_FILES_FOR_wx::wxhtml "${_IMPORT_PREFIX}/lib/libwx_gtk3u_html-3.2.so.0.0.0" )

# Import target "wx::wxpropgrid" for configuration "None"
set_property(TARGET wx::wxpropgrid APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxpropgrid PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_propgrid-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_propgrid-3.2.so.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS wx::wxpropgrid )
list(APPEND _IMPORT_CHECK_FILES_FOR_wx::wxpropgrid "${_IMPORT_PREFIX}/lib/libwx_gtk3u_propgrid-3.2.so.0.0.0" )

# Import target "wx::wxribbon" for configuration "None"
set_property(TARGET wx::wxribbon APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxribbon PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_ribbon-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_ribbon-3.2.so.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS wx::wxribbon )
list(APPEND _IMPORT_CHECK_FILES_FOR_wx::wxribbon "${_IMPORT_PREFIX}/lib/libwx_gtk3u_ribbon-3.2.so.0.0.0" )

# Import target "wx::wxrichtext" for configuration "None"
set_property(TARGET wx::wxrichtext APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxrichtext PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "wx::wxhtml;wx::wxxml"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_richtext-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_richtext-3.2.so.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS wx::wxrichtext )
list(APPEND _IMPORT_CHECK_FILES_FOR_wx::wxrichtext "${_IMPORT_PREFIX}/lib/libwx_gtk3u_richtext-3.2.so.0.0.0" )

# Import target "wx::wxwebview" for configuration "None"
set_property(TARGET wx::wxwebview APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxwebview PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_webview-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_webview-3.2.so.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS wx::wxwebview )
list(APPEND _IMPORT_CHECK_FILES_FOR_wx::wxwebview "${_IMPORT_PREFIX}/lib/libwx_gtk3u_webview-3.2.so.0.0.0" )

# Import target "wx::wxstc" for configuration "None"
set_property(TARGET wx::wxstc APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxstc PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_stc-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_stc-3.2.so.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS wx::wxstc )
list(APPEND _IMPORT_CHECK_FILES_FOR_wx::wxstc "${_IMPORT_PREFIX}/lib/libwx_gtk3u_stc-3.2.so.0.0.0" )

# Import target "wx::wxxrc" for configuration "None"
set_property(TARGET wx::wxxrc APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxxrc PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "wx::wxhtml;wx::wxxml"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_xrc-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_xrc-3.2.so.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS wx::wxxrc )
list(APPEND _IMPORT_CHECK_FILES_FOR_wx::wxxrc "${_IMPORT_PREFIX}/lib/libwx_gtk3u_xrc-3.2.so.0.0.0" )

# Import target "wx::wxmedia" for configuration "None"
set_property(TARGET wx::wxmedia APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxmedia PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_media-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_media-3.2.so.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS wx::wxmedia )
list(APPEND _IMPORT_CHECK_FILES_FOR_wx::wxmedia "${_IMPORT_PREFIX}/lib/libwx_gtk3u_media-3.2.so.0.0.0" )

# Import target "wx::wxgl" for configuration "None"
set_property(TARGET wx::wxgl APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxgl PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_gl-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_gl-3.2.so.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS wx::wxgl )
list(APPEND _IMPORT_CHECK_FILES_FOR_wx::wxgl "${_IMPORT_PREFIX}/lib/libwx_gtk3u_gl-3.2.so.0.0.0" )

# Import target "wx::wxqa" for configuration "None"
set_property(TARGET wx::wxqa APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxqa PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_qa-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_qa-3.2.so.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS wx::wxqa )
list(APPEND _IMPORT_CHECK_FILES_FOR_wx::wxqa "${_IMPORT_PREFIX}/lib/libwx_gtk3u_qa-3.2.so.0.0.0" )

# Import target "wx::wxxml" for configuration "None"
set_property(TARGET wx::wxxml APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxxml PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_baseu_xml-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_baseu_xml-3.2.so.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS wx::wxxml )
list(APPEND _IMPORT_CHECK_FILES_FOR_wx::wxxml "${_IMPORT_PREFIX}/lib/libwx_baseu_xml-3.2.so.0.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> wxwidgets-common-3.2.0-5-x86_64.pkg.tar.zst: usr/lib/cmake/wxWidgets/wxWidgetsTargets-none.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "None".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "wx::wxbase" for configuration "None"
set_property(TARGET wx::wxbase APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxbase PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_baseu-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_baseu-3.2.so.0"
  )

list(APPEND _cmake_import_check_targets wx::wxbase )
list(APPEND _cmake_import_check_files_for_wx::wxbase "${_IMPORT_PREFIX}/lib/libwx_baseu-3.2.so.0.0.0" )

# Import target "wx::wxnet" for configuration "None"
set_property(TARGET wx::wxnet APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxnet PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_baseu_net-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_baseu_net-3.2.so.0"
  )

list(APPEND _cmake_import_check_targets wx::wxnet )
list(APPEND _cmake_import_check_files_for_wx::wxnet "${_IMPORT_PREFIX}/lib/libwx_baseu_net-3.2.so.0.0.0" )

# Import target "wx::wxcore" for configuration "None"
set_property(TARGET wx::wxcore APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxcore PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_core-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_core-3.2.so.0"
  )

list(APPEND _cmake_import_check_targets wx::wxcore )
list(APPEND _cmake_import_check_files_for_wx::wxcore "${_IMPORT_PREFIX}/lib/libwx_gtk3u_core-3.2.so.0.0.0" )

# Import target "wx::wxadv" for configuration "None"
set_property(TARGET wx::wxadv APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxadv PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_adv-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_adv-3.2.so.0"
  )

list(APPEND _cmake_import_check_targets wx::wxadv )
list(APPEND _cmake_import_check_files_for_wx::wxadv "${_IMPORT_PREFIX}/lib/libwx_gtk3u_adv-3.2.so.0.0.0" )

# Import target "wx::wxaui" for configuration "None"
set_property(TARGET wx::wxaui APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxaui PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_aui-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_aui-3.2.so.0"
  )

list(APPEND _cmake_import_check_targets wx::wxaui )
list(APPEND _cmake_import_check_files_for_wx::wxaui "${_IMPORT_PREFIX}/lib/libwx_gtk3u_aui-3.2.so.0.0.0" )

# Import target "wx::wxhtml" for configuration "None"
set_property(TARGET wx::wxhtml APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxhtml PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_html-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_html-3.2.so.0"
  )

list(APPEND _cmake_import_check_targets wx::wxhtml )
list(APPEND _cmake_import_check_files_for_wx::wxhtml "${_IMPORT_PREFIX}/lib/libwx_gtk3u_html-3.2.so.0.0.0" )

# Import target "wx::wxpropgrid" for configuration "None"
set_property(TARGET wx::wxpropgrid APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxpropgrid PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_propgrid-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_propgrid-3.2.so.0"
  )

list(APPEND _cmake_import_check_targets wx::wxpropgrid )
list(APPEND _cmake_import_check_files_for_wx::wxpropgrid "${_IMPORT_PREFIX}/lib/libwx_gtk3u_propgrid-3.2.so.0.0.0" )

# Import target "wx::wxribbon" for configuration "None"
set_property(TARGET wx::wxribbon APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxribbon PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_ribbon-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_ribbon-3.2.so.0"
  )

list(APPEND _cmake_import_check_targets wx::wxribbon )
list(APPEND _cmake_import_check_files_for_wx::wxribbon "${_IMPORT_PREFIX}/lib/libwx_gtk3u_ribbon-3.2.so.0.0.0" )

# Import target "wx::wxrichtext" for configuration "None"
set_property(TARGET wx::wxrichtext APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxrichtext PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "wx::wxhtml;wx::wxxml"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_richtext-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_richtext-3.2.so.0"
  )

list(APPEND _cmake_import_check_targets wx::wxrichtext )
list(APPEND _cmake_import_check_files_for_wx::wxrichtext "${_IMPORT_PREFIX}/lib/libwx_gtk3u_richtext-3.2.so.0.0.0" )

# Import target "wx::wxwebview" for configuration "None"
set_property(TARGET wx::wxwebview APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxwebview PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_webview-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_webview-3.2.so.0"
  )

list(APPEND _cmake_import_check_targets wx::wxwebview )
list(APPEND _cmake_import_check_files_for_wx::wxwebview "${_IMPORT_PREFIX}/lib/libwx_gtk3u_webview-3.2.so.0.0.0" )

# Import target "wx::wxstc" for configuration "None"
set_property(TARGET wx::wxstc APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxstc PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_stc-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_stc-3.2.so.0"
  )

list(APPEND _cmake_import_check_targets wx::wxstc )
list(APPEND _cmake_import_check_files_for_wx::wxstc "${_IMPORT_PREFIX}/lib/libwx_gtk3u_stc-3.2.so.0.0.0" )

# Import target "wx::wxxrc" for configuration "None"
set_property(TARGET wx::wxxrc APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxxrc PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NONE "wx::wxhtml;wx::wxxml"
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_xrc-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_xrc-3.2.so.0"
  )

list(APPEND _cmake_import_check_targets wx::wxxrc )
list(APPEND _cmake_import_check_files_for_wx::wxxrc "${_IMPORT_PREFIX}/lib/libwx_gtk3u_xrc-3.2.so.0.0.0" )

# Import target "wx::wxmedia" for configuration "None"
set_property(TARGET wx::wxmedia APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxmedia PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_media-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_media-3.2.so.0"
  )

list(APPEND _cmake_import_check_targets wx::wxmedia )
list(APPEND _cmake_import_check_files_for_wx::wxmedia "${_IMPORT_PREFIX}/lib/libwx_gtk3u_media-3.2.so.0.0.0" )

# Import target "wx::wxgl" for configuration "None"
set_property(TARGET wx::wxgl APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxgl PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_gl-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_gl-3.2.so.0"
  )

list(APPEND _cmake_import_check_targets wx::wxgl )
list(APPEND _cmake_import_check_files_for_wx::wxgl "${_IMPORT_PREFIX}/lib/libwx_gtk3u_gl-3.2.so.0.0.0" )

# Import target "wx::wxqa" for configuration "None"
set_property(TARGET wx::wxqa APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxqa PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_gtk3u_qa-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_gtk3u_qa-3.2.so.0"
  )

list(APPEND _cmake_import_check_targets wx::wxqa )
list(APPEND _cmake_import_check_files_for_wx::wxqa "${_IMPORT_PREFIX}/lib/libwx_gtk3u_qa-3.2.so.0.0.0" )

# Import target "wx::wxxml" for configuration "None"
set_property(TARGET wx::wxxml APPEND PROPERTY IMPORTED_CONFIGURATIONS NONE)
set_target_properties(wx::wxxml PROPERTIES
  IMPORTED_LOCATION_NONE "${_IMPORT_PREFIX}/lib/libwx_baseu_xml-3.2.so.0.0.0"
  IMPORTED_SONAME_NONE "libwx_baseu_xml-3.2.so.0"
  )

list(APPEND _cmake_import_check_targets wx::wxxml )
list(APPEND _cmake_import_check_files_for_wx::wxxml "${_IMPORT_PREFIX}/lib/libwx_baseu_xml-3.2.so.0.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
